@@ -3,19 +3,19 @@ import requests
 import subprocess
 import wget
 import zipfile
+import sys
 
 
 def download_latest_version(version_number, driver_directory):
     """Download latest version of chromedriver to a specified directory.
-
-    :param driver_directory: Directory to save and download chromedriver.exe into.
+    :param driver_directory: Directory to save and download chromedriver files into.
     :type driver_directory: str
-    :param version_number: Latest chromedriver release from chromedriver.storage.googleapis.com.
+    :param version_number: Latest online chromedriver release from chromedriver.storage.googleapis.com.
     :type version_number: str
     :return: None
-    """
-    print("Attempting to download latest driver online......")
-    download_url = "https://chromedriver.storage.googleapis.com/" + version_number + "/chromedriver_win32.zip"
+    """ 
+    print("Attempting to download latest available driver ......")
+    download_url = "https://chromedriver.storage.googleapis.com/" + version_number + "/chromedriver_" + obtain_os() + ".zip"
     print(download_url)
     # Download driver as a zip file to specified folder
     latest_driver_zip = wget.download(download_url, out=driver_directory)
@@ -23,7 +23,7 @@ def download_latest_version(version_number, driver_directory):
     with zipfile.ZipFile(latest_driver_zip, 'r') as downloaded_zip:
         # Extract contents from downloaded zip file to specified folder path
         downloaded_zip.extractall(path=driver_directory)
-        print(f"\nSuccessfully downloaded version {version_number} to:\n{driver_directory}")
+        print(f"\nSuccessfully downloaded chromedriver version {version_number} to:\n{driver_directory}")
     # Delete the zip file downloaded
     os.remove(latest_driver_zip)
     return
@@ -31,23 +31,21 @@ def download_latest_version(version_number, driver_directory):
 
 def check_driver(driver_directory):
     """Check local chromedriver version and compare it with latest available version online.
-
-    :param driver_directory: Directory to store chromedriver.exe. Required to add driver_directory to path before using.
+    :param driver_directory: Directory to store chromedriver executable. Required to add driver_directory to path before using.
     :type driver_directory: str
-    :return: True if chromedriver.exe is already in driver_directory, else chromedriver is automatically downloaded.
+    :return: True if chromedriver executable is already in driver_directory, else it is automatically downloaded.
     """
-    # Check for latest chromedriver version online
-    latest_release_url = "https://chromedriver.storage.googleapis.com/LATEST_RELEASE"
-    response = requests.get(latest_release_url)
-    online_driver_version = response.text
+    online_driver_version = get_latest_chromedriver_release()
     try:
         # Executes cmd line entry to check for existing web-driver version locally
+        os.chdir(driver_directory)
         cmd_run = subprocess.run("chromedriver --version",
                                  capture_output=True,
-                                 text=True)
+                                 text=True)     
     except FileNotFoundError:
+        os.chdir("..")
         # Handling case if chromedriver not found in path
-        print("No chromedriver.exe found in specified path\n")
+        print("No chromedriver executable found in specified path\n")
         download_latest_version(online_driver_version, driver_directory)
     else:
         # Extract local driver version number as string from terminal output
@@ -58,3 +56,23 @@ def check_driver(driver_directory):
             return True
         else:
             download_latest_version(online_driver_version, driver_directory)
+
+
+def get_latest_chromedriver_release():
+    """ Check for latest chromedriver release version online"""
+    latest_release_url = "https://chromedriver.storage.googleapis.com/LATEST_RELEASE"
+    response = requests.get(latest_release_url)
+    online_driver_version = response.text
+    return online_driver_version
+
+            
+def obtain_os():
+    """Obtains operating system based on chromedriver supported by from https://chromedriver.chromium.org/
+    :return: str"""
+    if sys.platform.startswith('win32'):
+        os_name='win32'
+    elif sys.platform.startswith('linux'):
+        os_name='linux64'
+    elif sys.platform.startswith('darwin'):
+        os_name='mac64'
+    return os_name
